==> xilinx-vcu-omx_2020.2.orig.tar.gz: vcu-omx-il-xilinx-v2020.2/module/mediatype_dec_itu.h <==
/******************************************************************************
*
* Copyright (C) 2016-2020 Allegro DVT2.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* Use of the Software is limited solely to applications:
* (a) running on a Xilinx device, or
* (b) that interact with a Xilinx device through a bus or interconnect.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* XILINX OR ALLEGRO DVT2 BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Except as contained in this notice, the name of  Xilinx shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Xilinx.
*
*
* Except as contained in this notice, the name of Allegro DVT2 shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Allegro DVT2.
*
******************************************************************************/

#pragma once

#include "module_structs.h"

#include <vector>

extern "C"
{
#include <lib_decode/lib_decode.h>
}

Clock CreateClock(AL_TDecSettings settings);
bool UpdateClock(AL_TDecSettings& settings, Clock clock);

int CreateInternalEntropyBuffer(AL_TDecSettings settings);
bool UpdateInternalEntropyBuffer(AL_TDecSettings& settings, int internalEntropyBuffer);

SequencePictureModeType CreateSequenceMode(AL_TDecSettings settings);
bool UpdateSequenceMode(AL_TDecSettings& settings, SequencePictureModeType sequenceMode, std::vector<SequencePictureModeType> sequenceModes);

Format CreateFormat(AL_TDecSettings settings);
bool UpdateFormat(AL_TDecSettings& settings, Format format, std::vector<ColorType> colors, std::vector<int> bitdepths, Stride& stride, StrideAlignments strideAlignments);

Resolution CreateResolution(AL_TDecSettings settings, Stride stride);
bool UpdateResolution(AL_TDecSettings& settings, Stride& stride, StrideAlignments strideAlignments, Resolution resolution);

BufferSizes CreateBufferSizes(AL_TDecSettings settings, Stride stride);

DecodedPictureBufferType CreateDecodedPictureBuffer(AL_TDecSettings settings);

bool UpdateIsEnabledSubframe(AL_TDecSettings& settings, bool isSubframeEnabled);

bool UpdateDecodedPictureBuffer(AL_TDecSettings& settings, DecodedPictureBufferType decodedPictureBuffer);

==> xilinx-vcu-omx_2022.1.orig.tar.gz: vcu-omx-il-xilinx_v2022.1/module/mediatype_dec_itu.h <==
/******************************************************************************
*
* Copyright (C) 2016-2020 Allegro DVT2.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* Use of the Software is limited solely to applications:
* (a) running on a Xilinx device, or
* (b) that interact with a Xilinx device through a bus or interconnect.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* XILINX OR ALLEGRO DVT2 BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Except as contained in this notice, the name of  Xilinx shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Xilinx.
*
*
* Except as contained in this notice, the name of Allegro DVT2 shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Allegro DVT2.
*
******************************************************************************/

#pragma once

#include "module_structs.h"

#include <vector>

extern "C"
{
#include <lib_decode/lib_decode.h>
}

Clock CreateClock(AL_TDecSettings settings);
bool UpdateClock(AL_TDecSettings& settings, Clock clock);

int CreateInternalEntropyBuffer(AL_TDecSettings settings);
bool UpdateInternalEntropyBuffer(AL_TDecSettings& settings, int internalEntropyBuffer);

SequencePictureModeType CreateSequenceMode(AL_TDecSettings settings);
bool UpdateSequenceMode(AL_TDecSettings& settings, SequencePictureModeType sequenceMode, std::vector<SequencePictureModeType> sequenceModes);

Format CreateFormat(AL_TDecSettings settings);
bool UpdateFormat(AL_TDecSettings& settings, Format format, std::vector<ColorType> colors, std::vector<int> bitdepths, Stride& stride, StrideAlignments strideAlignments);

Resolution CreateResolution(AL_TDecSettings settings, Stride stride);
bool UpdateResolution(AL_TDecSettings& settings, Stride& stride, StrideAlignments strideAlignments, Resolution resolution);

BufferSizes CreateBufferSizes(AL_TDecSettings settings, Stride stride);

DecodedPictureBufferType CreateDecodedPictureBuffer(AL_TDecSettings settings);

bool UpdateIsEnabledSubframe(AL_TDecSettings& settings, bool isSubframeEnabled);

bool UpdateDecodedPictureBuffer(AL_TDecSettings& settings, DecodedPictureBufferType decodedPictureBuffer);

Point<int> CreateOutputPosition(AL_TDecSettings settings);
bool UpdateOutputPosition(AL_TDecSettings& settings, Point<int> position);
